@@ -2806,9 +2806,9 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     char* env = getenv("SAPHIRE_TMPDIR");
     if(env) 
-        strncpy(gTmpDir, env, PATH_MAX);
+        xstrncpy(gTmpDir, env, PATH_MAX);
     else 
-        strncpy(gTmpDir, "/tmp", PATH_MAX);
+        xstrncpy(gTmpDir, "/tmp", PATH_MAX);
 
     gMatchRestart = HASH_NEW(1000);
     gStackTraceFName = VECTOR_NEW(30);
@@ -3735,7 +3735,7 @@ void saphire_make_var_completion_list()
         char* key = hash_loop_key(it);
 
         char env_name[1024];
-        strncpy(env_name, key, 1024);
+        xstrncpy(env_name, key, 1024);
 
         vector_add(gSaphireVarCompletions, STRING_NEW(env_name));
 
@@ -3747,7 +3747,7 @@ void saphire_make_var_completion_list()
         char* key = hash_loop_key(it);
 
         char env_name[1024];
-        strncpy(env_name, key, 1024);
+        xstrncpy(env_name, key, 1024);
 
         vector_add(gSaphireVarCompletions, STRING_NEW(env_name));
 
@@ -3759,7 +3759,7 @@ void saphire_make_var_completion_list()
         char* key = hash_loop_key(it);
 
         char env_name[1024];
-        strncpy(env_name, key, 1024);
+        xstrncpy(env_name, key, 1024);
 
         vector_add(gSaphireVarCompletions, STRING_NEW(env_name));
 
